==> lxqt-config_0.17.1.orig.tar.xz: lxqt-config-0.17.1/lxqt-config-brightness/translations/lxqt-config-brightness_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>BrightnessSettings</name>
    <message>
        <location filename="../brightnesssettings.ui" line="14"/>
        <source>Brightness Settings</source>
        <translation>Ryškumo nustatymai</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="35"/>
        <location filename="../brightnesssettings.ui" line="74"/>
        <source>☀</source>
        <translation>☀</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="42"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Backlight and brightness settings:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Foninio apšvietimo ir ryškumo nustatymai:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="51"/>
        <source>Backlight</source>
        <translation>Foninis apšvietimas</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="57"/>
        <source>☼</source>
        <translation>☼</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="87"/>
        <source>Brightness</source>
        <translation>Ryškumas</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="105"/>
        <source>Require confirmation after settings change</source>
        <translation>Po nustatymų pakeitimo, reikalauti patvirtinimo</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.cpp" line="112"/>
        <source>Brightness settings changed</source>
        <translation>Ryškumo nustatymai pakeisti</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.cpp" line="113"/>
        <source>Confirmation required. Are the settings correct?</source>
        <translation>Reikalingas patvirtinimas. Ar nustatymai teisingi?</translation>
    </message>
</context>
<context>
    <name>OutputWidget</name>
    <message>
        <location filename="../outputwidget.ui" line="38"/>
        <source>&lt;b&gt;Output:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Išvestis:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../outputwidget.ui" line="48"/>
        <source>☼</source>
        <translation>☼</translation>
    </message>
    <message>
        <location filename="../outputwidget.ui" line="80"/>
        <source>☀</source>
        <translation>☀</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="68"/>
        <source>Increase brightness.</source>
        <translation>Padidinti ryškumą.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>Decrease brightness.</source>
        <translation>Sumažinti ryškumą.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>Set brightness from 1 to 100.</source>
        <translation>Nustatyti ryškumą nuo 1 iki 100.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>Reset gamma to default value.</source>
        <translation>Atstatyti gamą į numatytąją reikšmę.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="112"/>
        <source>%1: Can&apos;t use increase/decrease and set in conjunction</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="117"/>
        <source>%1: Can&apos;t use increase and decrease options in conjunction</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lxqt-config-2.1.0.tar.xz: lxqt-config-2.1.0/lxqt-config-brightness/translations/lxqt-config-brightness_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>BrightnessSettings</name>
    <message>
        <location filename="../brightnesssettings.ui" line="14"/>
        <source>Brightness Settings</source>
        <translation>Ryškumo nustatymai</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="35"/>
        <location filename="../brightnesssettings.ui" line="74"/>
        <source>☀</source>
        <translation>☀</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="42"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Backlight and brightness settings:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Foninio apšvietimo ir ryškumo nustatymai:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="51"/>
        <source>Backlight</source>
        <translation>Foninis apšvietimas</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="57"/>
        <source>☼</source>
        <translation>☼</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="87"/>
        <source>Brightness</source>
        <translation>Ryškumas</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="105"/>
        <source>Require confirmation after settings change</source>
        <translation>Po nustatymų pakeitimo, reikalauti patvirtinimo</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.cpp" line="112"/>
        <source>Brightness settings changed</source>
        <translation>Ryškumo nustatymai pakeisti</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.cpp" line="113"/>
        <source>Confirmation required. Are the settings correct?</source>
        <translation>Reikalingas patvirtinimas. Ar nustatymai teisingi?</translation>
    </message>
</context>
<context>
    <name>OutputWidget</name>
    <message>
        <location filename="../outputwidget.ui" line="38"/>
        <source>&lt;b&gt;Output:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Išvestis:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../outputwidget.ui" line="48"/>
        <source>☼</source>
        <translation>☼</translation>
    </message>
    <message>
        <location filename="../outputwidget.ui" line="80"/>
        <source>☀</source>
        <translation>☀</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="68"/>
        <source>Increase brightness.</source>
        <translation>Padidinti ryškumą.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>Decrease brightness.</source>
        <translation>Sumažinti ryškumą.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>Set brightness from 1 to 100.</source>
        <translation>Nustatyti ryškumą nuo 1 iki 100.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>Reset gamma to default value.</source>
        <translation>Atstatyti gamą į numatytąją reikšmę.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="112"/>
        <source>%1: Can&apos;t use increase/decrease and set in conjunction</source>
        <translation>%1: Negalima naudoti „increase/decrease“ kartu su „set“</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="117"/>
        <source>%1: Can&apos;t use increase and decrease options in conjunction</source>
        <translation>%1: Negalima naudoti „increase“ kartu su „decrease“</translation>
    </message>
</context>
</TS>
